Miscellaneous routines
======================

.. toctree::

.. currentmodule:: numpy

Performance tuning
------------------
.. autosummary::
   :toctree: generated/

   setbufsize
   getbufsize

Memory ranges
-------------

.. autosummary::
   :toctree: generated/

   shares_memory
   may_share_memory

Utility
-------

.. autosummary::
   :toctree: generated/

   get_include
   show_config
   show_runtime
   broadcast_shapes

NumPy-specific help function
----------------------------

.. autosummary::
   :toctree: generated/

   info
